Changelog
=========

0.9.4 (2017-08-21)
------------------

- Add support for serializing plone.app.textfield RichTextValues
  [datakurre]

0.9.3 (2017-04-24)
------------------

- Fix issue where schema_compatible was unable to deserializer BytesLine from unicode string
  [datakurre]


0.9.2 (2017-01-24)
------------------

- Fix issue where deserializer failed when value had extra fields to target
  schema
  [datakurre]


0.9.1 (2016-09-09)
------------------

- Add zope.schema.Bool adapter for ISchemaCompatible
  [datakurre]


0.9.0 (2016-09-08)
------------------

- First release.
